@@ -1,8 +1,8 @@
 ;;; abyss-theme.el --- A dark theme with contrasting colours.
 
-;; Author: Matt Russell <mgrbyte@member.fsf.org>
-;; Package-Version: 0.7.2
-;; Package-Revision: v0.7.2-0-g6eb2b5735808
+;; Author: Matt Russell <m.russell@bangor.ac.uk>
+;; Package-Version: 20260103.1924
+;; Package-Revision: e8326ed9955d
 ;; Filename: abyss-theme.el
 ;; Package-Requires: ((emacs "24"))
 ;; Keywords: theme, dark, contrasting colours
@@ -66,38 +66,11 @@
    `(gui-element
         ((t (:foreground ,abyss/background2 :background ,abyss/foreground))))
    `(mode-line
-     ((t (:foreground ,abyss/background :background ,abyss/skyblue :box nil))))
+     ((t (:foreground ,abyss/background2 :background ,abyss/skyblue :box nil))))
    `(mode-line-highlight
-     ((t (:foreground ,abyss/white :weight bold :box nil))))
-   `(mode-line-emphasis
-     ((t (:foreground ,abyss/background :weight bold))))
-   `(mode-line-buffer-id
-     ((t (:foreground ,abyss/background :weight bold))))
+     ((t (:foreground ,abyss/vanilla-cream :box nil))))
    `(mode-line-inactive
      ((t (:foreground ,abyss/redpurple :background ,abyss/background2 :box nil))))
-   ;; Standard faces used by many packages (e.g. envrc, flycheck, lsp)
-   ;; These need good contrast on both dark background and skyblue mode-line
-   `(success ((t (:foreground ,abyss/bluegreen :weight bold))))
-   `(warning ((t (:foreground ,abyss/background :weight bold))))
-   `(error ((t (:foreground ,abyss/scarlet :weight bold))))
-   ;; Envrc mode-line faces (explicit override, clear inherit to prevent fallback)
-   `(envrc-mode-line-on-face ((t (:inherit nil :foreground ,abyss/bluegreen :weight bold))))
-   `(envrc-mode-line-error-face ((t (:inherit nil :foreground ,abyss/scarlet :weight bold))))
-   `(envrc-mode-line-none-face ((t (:inherit nil :foreground ,abyss/background :weight bold))))
-   ;; Flycheck mode-line faces
-   `(flycheck-error ((t (:foreground ,abyss/scarlet :weight bold))))
-   `(flycheck-warning ((t (:foreground ,abyss/background :weight bold))))
-   `(flycheck-info ((t (:foreground ,abyss/bluegreen :weight bold))))
-   `(flycheck-fringe-error ((t (:foreground ,abyss/scarlet))))
-   `(flycheck-fringe-warning ((t (:foreground ,abyss/orange))))
-   `(flycheck-fringe-info ((t (:foreground ,abyss/bluegreen))))
-   ;; Compilation faces (used by lsp-mode and others)
-   `(compilation-error ((t (:foreground ,abyss/scarlet :weight bold))))
-   `(compilation-warning ((t (:foreground ,abyss/background :weight bold))))
-   `(compilation-info ((t (:foreground ,abyss/bluegreen :weight bold))))
-   `(compilation-mode-line-exit ((t (:foreground ,abyss/bluegreen :weight bold))))
-   `(compilation-mode-line-fail ((t (:foreground ,abyss/scarlet :weight bold))))
-   `(compilation-mode-line-run ((t (:foreground ,abyss/background :weight bold))))
    `(text-cursor
         ((t (:foreground ,abyss/foreground :background ,abyss/background))))
    `(region
